@@ -106,9 +106,9 @@ print(Gci)
     {Label<-readline("Enter a behavior variable label ")
     ES<-data.frame(ES,V,Label)
   
-    write.csv(ES,file = file.choose(new = T),row.names=FALSE)
     
-  #write.csv(ES,file = tclvalue(tcl('tk_getSaveFile')),row.names=FALSE)
+    write.csv(ES,file = tclvalue(tkgetSaveFile()),row.names=FALSE)
+  
     
    } 
 
@@ -125,7 +125,9 @@ print(Gci)
             writeLines(" ")
             writeLines("*****************save appended file***************************")  
             
-            write.csv(out,file = file.choose(new = T),row.names=FALSE)}
-  #write.csv(out,file = tclvalue(tcl('tk_getSaveFile')),row.names=FALSE) }
+            
   
+  write.csv(out,file = tclvalue(tkgetSaveFile()),row.names=FALSE)}
+  #write.csv(out,file = tclvalue(tcl('tk_getSaveFile')),row.names=FALSE) }
+            
 }
